.. _app-examples:

Application examples
####################

Usually, the best way to learn is to look at application examples!

An open Wiki page gives `a complete list of apps in the wild <https://github.com/Kinto/kinto/wiki/App-examples>`_!

.. important::

    We would be delighted to highlight demos, use-cases, tutorials,
    or applications made by the community, so don't hesitate to
    `add a link to yours <https://github.com/Kinto/kinto/wiki/App-examples/_edit>`_!
